@@ -1,17 +1,11 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import logging
 import os
 import re
 
-import six
-
 from . import errors
 from .. import config
 from .. import parallel
 from ..config.environment import Environment
-from ..const import API_VERSIONS
 from ..const import LABEL_CONFIG_FILES
 from ..const import LABEL_ENVIRONMENT_FILE
 from ..const import LABEL_WORKING_DIR
@@ -71,7 +65,6 @@ def project_from_options(project_dir, options, additional_options=None):
         context=context,
         environment=environment,
         override_dir=override_dir,
-        compatibility=compatibility_from_options(project_dir, options, environment),
         interpolate=(not additional_options.get('--no-interpolate')),
         environment_file=environment_file
     )
@@ -103,14 +96,13 @@ def get_config_from_options(base_dir, options, additional_options=None):
     )
     return config.load(
         config.find(base_dir, config_path, environment, override_dir),
-        compatibility_from_options(config_path, options, environment),
         not additional_options.get('--no-interpolate')
     )
 
 
 def get_config_path_from_options(base_dir, options, environment):
     def unicode_paths(paths):
-        return [p.decode('utf-8') if isinstance(p, six.binary_type) else p for p in paths]
+        return [p.decode('utf-8') if isinstance(p, bytes) else p for p in paths]
 
     file_option = options.get('--file')
     if file_option:
@@ -125,18 +117,16 @@ def get_config_path_from_options(base_dir, options, environment):
 
 def get_project(project_dir, config_path=None, project_name=None, verbose=False,
                 context=None, environment=None, override_dir=None,
-                compatibility=False, interpolate=True, environment_file=None):
+                interpolate=True, environment_file=None):
     if not environment:
         environment = Environment.from_env_file(project_dir)
     config_details = config.find(project_dir, config_path, environment, override_dir)
     project_name = get_project_name(
         config_details.working_dir, project_name, environment
     )
-    config_data = config.load(config_details, compatibility, interpolate)
+    config_data = config.load(config_details, interpolate)
 
-    api_version = environment.get(
-        'COMPOSE_API_VERSION',
-        API_VERSIONS[config_data.version])
+    api_version = environment.get('COMPOSE_API_VERSION')
 
     client = get_client(
         verbose=verbose, version=api_version, context=context, environment=environment
@@ -154,15 +144,17 @@ def get_project(project_dir, config_path=None, project_name=None, verbose=False,
 
 def execution_context_labels(config_details, environment_file):
     extra_labels = [
-        '{0}={1}'.format(LABEL_WORKING_DIR, os.path.abspath(config_details.working_dir))
+        '{}={}'.format(LABEL_WORKING_DIR, os.path.abspath(config_details.working_dir))
     ]
 
     if not use_config_from_stdin(config_details):
-        extra_labels.append('{0}={1}'.format(LABEL_CONFIG_FILES, config_files_label(config_details)))
+        extra_labels.append('{}={}'.format(LABEL_CONFIG_FILES, config_files_label(config_details)))
 
     if environment_file is not None:
-        extra_labels.append('{0}={1}'.format(LABEL_ENVIRONMENT_FILE,
-                                             os.path.normpath(environment_file)))
+        extra_labels.append('{}={}'.format(
+            LABEL_ENVIRONMENT_FILE,
+            os.path.normpath(environment_file))
+            )
     return extra_labels
 
 
@@ -175,7 +167,8 @@ def use_config_from_stdin(config_details):
 
 def config_files_label(config_details):
     return ",".join(
-        map(str, (os.path.normpath(c.filename) for c in config_details.config_files)))
+        os.path.normpath(c.filename) for c in config_details.config_files
+        )
 
 
 def get_project_name(working_dir, project_name=None, environment=None):
@@ -193,13 +186,3 @@ def get_project_name(working_dir, project_name=None, environment=None):
         return normalize_name(project)
 
     return 'default'
-
-
-def compatibility_from_options(working_dir, options=None, environment=None):
-    """Get compose v3 compatibility from --compatibility option
-       or from COMPOSE_COMPATIBILITY environment variable."""
-
-    compatibility_option = options.get('--compatibility')
-    compatibility_environment = environment.get_boolean('COMPOSE_COMPATIBILITY')
-
-    return compatibility_option or compatibility_environment
